Struct google_cloudresourcemanager3::api::TagBinding[][src]

pub struct TagBinding {
    pub name: Option<String>,
    pub parent: Option<String>,
    pub tag_value: Option<String>,
}

A TagBinding represents a connection between a TagValue and a cloud resource (currently project, folder, or organization). Once a TagBinding is created, the TagValue is applied to all the descendants of the cloud resource.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

name: Option<String>

Output only. The name of the TagBinding. This is a String of the form: tagBindings/{full-resource-name}/{tag-value-name} (e.g. tagBindings/%2F%2Fcloudresourcemanager.googleapis.com%2Fprojects%2F123/tagValues/456).

parent: Option<String>

The full resource name of the resource the TagValue is bound to. E.g. //cloudresourcemanager.googleapis.com/projects/123

tag_value: Option<String>

The TagValue of the TagBinding. Must be of the form tagValues/456.